@@ -17,8 +17,8 @@ package ODF::MailMerge;
 # ...but don't let CPAN or test harnes scanners see this as defining $VERSION
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 999.999; }
 
-our $VERSION = '1.001'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-09-17'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '1.002'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-09-18'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Carp;
 our @CARP_NOT = ("ODF::lpOD_Helper", "ODF::lpOD");
@@ -905,7 +905,7 @@ sub add_record {
           };
   if ($@) { # filter out our internal stuff to make easier to read
     { local $_;
-      $@ =~ s/^[^\n]* called \Kat $__FILE__ line .*?(?=\s*${__PACKAGE__}::add_record)/from [MM internals]/msg
+      $@ =~ s/^[^\n]* called \Kat \Q${__FILE__}\E line .*?(?=\s*\Q${__PACKAGE__}\E::add_record)/from [MM internals]/msg
         unless $opts{debug};
     }
     die "$@\n";
